"""Module for connecting to the unofficial Owlet API. Code taken from:
https://github.com/bobcat0070/python-owlet
https://github.com/tescalada/python-owlet
https://github.com/arosequist/node-owlet

with inspiration from
https://github.com/jterrace/pyharmony/tree/master/harmony

GPL-3.0
 """